/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.util.event.api;



/**
 * Define methods needed to register listeners and dispatch events.
 * @author missonng
 */
public interface IEventDispatcher {
    /**
     * Add an event listener.
     * @param listener The event listener to add.
     */
    void addListener(IEventListener listener);

    /**
     * Remove an event listener.
     * @param listener The event listener to remove.
     */
    void removeListener(IEventListener listener);

    /**
     * Dispatch this event.
     * @param event The event to dispatch.
     * @return A token to manage the event processing.
     */
    IEventToken dispatch(final IEvent event);

    /**
     * Dispatch an event.
     * @param event The event to dispatch.
     * @param timeout The maximum time dispatch waits for synchronous listeners to process.
     * @return A token to manage the event processing.
     */
    IEventToken dispatch(final IEvent event, final long timeout);
}
