/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.util.event.api;

import org.ow2.util.event.api.exception.EventFilterMalformed;
import org.ow2.util.event.api.exception.EventIdAlreadyExists;
import org.ow2.util.event.api.exception.EventIdMalformed;
import org.ow2.util.event.api.exception.EventIdNotExists;

/**
 * Define a root event dispatcher, and manage a provider tree using a hierarchical naming convention.
 * By default, created provider will use their parent event dispatcher, but they can redefine their own one.
 * Listener are registered in the service using a filter on provider ids.<br>
 * The service use this filter to register the listener on all matching providers.
 * @author missonng
 */
public interface IEventService {
    /**
     * Create and return a new event provider with the specified id.
     * @param id The event provider id.
     * @return The event provider.
     * @throws EventIdMalformed If the id does not match the regexp : (/\w+)+
     * @throws EventIdAlreadyExists If a provider with this id already exists.
     */
    IEventProvider createProvider(String id) throws EventIdMalformed, EventIdAlreadyExists;

    /**
     * Destroy an new event provider with the specified id.
     * @param id The event provider id.
     * @throws EventIdNotExists If no provider with this id exists.
     */
    void destroyProvider(String id) throws EventIdNotExists;

    /**
     * Register a listener on all provider matching the filter.
     * @param listener The listener to register.
     * @param filter The filter to apply.
     * @throws EventFilterMalformed If the filter does not match the regexp : (/[\w\*]+)+
     */
    void registerListener(IEventListener listener, String filter) throws EventFilterMalformed;

    /**
     * Unregister an event listener.
     * @param listener The event listener to unregister.
     */
    void unregisterListener(IEventListener listener);

    /**
     * Start the service.
     */
    void start();

    /**
     * Stop the service.
     */
    void stop();
}
